@@ -27,8 +27,8 @@ import pytest
 from requests import exceptions as requests_exceptions
 from requests.models import Response
 
-from airflow.exceptions import AirflowException
 from airflow.models.connection import Connection
+from airflow.providers.common.compat.sdk import AirflowException
 from airflow.providers.dbt.cloud.hooks.dbt import (
     DBT_CAUSE_MAX_LENGTH,
     DbtCloudHook,
@@ -39,10 +39,7 @@ from airflow.providers.dbt.cloud.hooks.dbt import (
     fallback_to_default_account,
 )
 
-try:
-    from airflow.sdk import timezone
-except ImportError:
-    from airflow.utils import timezone  # type: ignore[attr-defined,no-redef]
+from tests_common.test_utils.compat import timezone
 
 ACCOUNT_ID_CONN = "account_id_conn"
 NO_ACCOUNT_ID_CONN = "no_account_id_conn"
@@ -205,7 +202,7 @@ class TestDbtCloudHook:
         create_connection_without_db(proxy_conn)
 
     @pytest.mark.parametrize(
-        argnames="conn_id, url",
+        argnames=("conn_id", "url"),
         argvalues=[(ACCOUNT_ID_CONN, BASE_URL), (SINGLE_TENANT_CONN, SINGLE_TENANT_URL)],
         ids=["multi-tenant", "single-tenant"],
     )
@@ -216,7 +213,7 @@ class TestDbtCloudHook:
         assert hook.dbt_cloud_conn_id == conn_id
 
     @pytest.mark.parametrize(
-        argnames="conn_id, url",
+        argnames=("conn_id", "url"),
         argvalues=[(ACCOUNT_ID_CONN, BASE_URL), (SINGLE_TENANT_CONN, SINGLE_TENANT_URL)],
         ids=["multi-tenant", "single-tenant"],
     )
@@ -226,7 +223,7 @@ class TestDbtCloudHook:
         assert hook.base_url == url
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -249,7 +246,7 @@ class TestDbtCloudHook:
                 fallback_to_default_account(dbt_cloud_func)(hook)
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -264,7 +261,7 @@ class TestDbtCloudHook:
         hook._paginate.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -283,7 +280,7 @@ class TestDbtCloudHook:
         hook._paginate.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -304,7 +301,7 @@ class TestDbtCloudHook:
         )
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id, name_contains",
+        argnames=("conn_id", "account_id", "name_contains"),
         argvalues=[(ACCOUNT_ID_CONN, None, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID, PROJECT_NAME)],
         ids=["default_account", "explicit_account"],
     )
@@ -327,7 +324,7 @@ class TestDbtCloudHook:
         )
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -346,7 +343,7 @@ class TestDbtCloudHook:
         hook._paginate.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -367,7 +364,7 @@ class TestDbtCloudHook:
         )
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id, name_contains",
+        argnames=("conn_id", "account_id", "name_contains"),
         argvalues=[(ACCOUNT_ID_CONN, None, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID, ENVIRONMENT_NAME)],
         ids=["default_account", "explicit_account"],
     )
@@ -390,7 +387,7 @@ class TestDbtCloudHook:
         )
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -411,7 +408,7 @@ class TestDbtCloudHook:
         hook._paginate.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -432,7 +429,7 @@ class TestDbtCloudHook:
         hook.run.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -464,7 +461,7 @@ class TestDbtCloudHook:
         hook.run.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -505,7 +502,7 @@ class TestDbtCloudHook:
         assert job_details == DEFAULT_LIST_JOBS_RESPONSE["data"][0]
 
     @pytest.mark.parametrize(
-        argnames="project_name, environment_name, job_name",
+        argnames=("project_name", "environment_name", "job_name"),
         argvalues=[
             ("dummy_name", ENVIRONMENT_NAME, JOB_NAME),
             (PROJECT_NAME, "dummy_name", JOB_NAME),
@@ -595,7 +592,7 @@ class TestDbtCloudHook:
                 )
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -617,7 +614,7 @@ class TestDbtCloudHook:
         hook._paginate.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -649,7 +646,7 @@ class TestDbtCloudHook:
         hook._paginate.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -684,7 +681,7 @@ class TestDbtCloudHook:
         hook._paginate.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -714,12 +711,12 @@ class TestDbtCloudHook:
         hook._paginate.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
     @pytest.mark.parametrize(
-        argnames="get_job_runs_data, should_use_rerun",
+        argnames=("get_job_runs_data", "should_use_rerun"),
         argvalues=[
             ([], False),
             ([{"status": DbtCloudJobRunStatus.QUEUED.value}], False),
@@ -773,7 +770,7 @@ class TestDbtCloudHook:
                 )
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(PROXY_CONN, ACCOUNT_ID)],
         ids=["proxy_connection"],
     )
@@ -795,7 +792,7 @@ class TestDbtCloudHook:
         hook._paginate.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -820,7 +817,7 @@ class TestDbtCloudHook:
         )
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -847,7 +844,7 @@ class TestDbtCloudHook:
         )
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -864,7 +861,7 @@ class TestDbtCloudHook:
         )
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -885,7 +882,7 @@ class TestDbtCloudHook:
         hook._paginate.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -953,7 +950,7 @@ class TestDbtCloudHook:
                     hook.wait_for_job_run_status(**config)
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -972,7 +969,7 @@ class TestDbtCloudHook:
         hook._paginate.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -993,7 +990,7 @@ class TestDbtCloudHook:
         hook._paginate.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -1014,7 +1011,7 @@ class TestDbtCloudHook:
         hook._paginate.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -1036,7 +1033,7 @@ class TestDbtCloudHook:
         hook._paginate.assert_not_called()
 
     @pytest.mark.parametrize(
-        argnames="conn_id, account_id",
+        argnames=("conn_id", "account_id"),
         argvalues=[(ACCOUNT_ID_CONN, None), (NO_ACCOUNT_ID_CONN, ACCOUNT_ID)],
         ids=["default_account", "explicit_account"],
     )
@@ -1147,7 +1144,7 @@ class TestDbtCloudHook:
         assert extra_options["proxies"] == EXTRA_PROXIES["proxies"]
 
     @pytest.mark.parametrize(
-        argnames="exception, expected",
+        argnames=("exception", "expected"),
         argvalues=[
             (requests_exceptions.ConnectionError(), True),
             (requests_exceptions.Timeout(), True),
@@ -1180,7 +1177,7 @@ class TestDbtCloudHook:
 
     @pytest.mark.asyncio
     @pytest.mark.parametrize(
-        "error_factory, retry_qty, retry_delay",
+        ("error_factory", "retry_qty", "retry_delay"),
         [
             (
                 lambda: aiohttp.ClientResponseError(
@@ -1230,7 +1227,7 @@ class TestDbtCloudHook:
 
     @pytest.mark.asyncio
     @pytest.mark.parametrize(
-        "error_factory, expected_exception",
+        ("error_factory", "expected_exception"),
         [
             (
                 lambda: aiohttp.ClientResponseError(
@@ -1268,7 +1265,7 @@ class TestDbtCloudHook:
 
     @pytest.mark.asyncio
     @pytest.mark.parametrize(
-        argnames="error_factory, expected_exception",
+        argnames=("error_factory", "expected_exception"),
         argvalues=[
             (
                 lambda: aiohttp.ClientResponseError(
